#include "dialog.h"
#include "ui_dialog.h"
#include <QFileDialog>
#include <QFile>
#include <QTextStream>
#include <QTextEdit>
#include <QtDebug>
#include <QMessageBox>
#include <QPrinter>
#include <QPrintDialog>
#include <QPalette>
#include <QColor>
#include <QBrush>

#define CABANALYST "CabAnalyst 1.0 on Linux"

Dialog::Dialog(QWidget *parent)
    : QDialog(parent), ui(new Ui::Dialog)
{
    ui->setupUi(this);
    // Listing of all the Cabrillo offically supported contest names
    contestlist << "<empty>" << "AP-SPRINT" << "ARRL-10" << "ARRL-160" << "ARRL-DX-CW" << "ARRL-DX-SSB";
    contestlist << "ARRL-SS-CW" << "ARRL-SS-SSB" << "ARRL-UHF-AUG" << "ARRL-VHF-JAN" << " ARRL-VHF-JUN";
    contestlist << "ARRL-VHF-SEP" << "ARRL-RTTY" << "BARTG-RTTY" << "CQ-160-CW" << "CQ-160-SSB";
    contestlist << "CQ-WPX-CW" << "CQ-WPX-RTTY" << "CQ-WPX-SSB" << "CQ-VHF" << "CQ-WW-CW";
    contestlist << "CQ-WW-RTTY" << "CQ-WW-SSB" << "DARC-WAEDC-CW" << "DARC-WAEDC-RTTY" << "DARC-WAEDC-SSB";
    contestlist << "FCG-FQP" << "IARU-HF" << "JIDX-CW" << "JIDX-SSB" << "NAQP-CW";
    contestlist << "NAQP-RTTY" << "NAQP-SSB" << "NA-SPRINT-CW" << "NA-SPRINT-SSB" << "NCCC-CQP";
    contestlist << "NEQP" << "OCEANIA-DX-CW" << "OCEANIA-DX-SSB" << "RDXC" << "RSGB-IOTA";
    contestlist << "SAC-CW" << "SAC-SSB" << "STEW-PERRY" << "TARA-RTTY" << "<other>";

    ui->contest_CB->addItems(contestlist);
    other_contest = "";

    // For my testing I want to default to my test log directory on start up.
    //filename = "/home/k6eep/ham/test_logs";
    filename = "";

}

Dialog::~Dialog()
{
    delete ui;
}

void Dialog::on_pushButton_2_clicked()
{

    filename = QFileDialog::getOpenFileName(this, tr("Select a logfile"), filename, tr("All files (*.*)"));
    QFile file(filename);
    if(!file.open(QIODevice::ReadOnly | QIODevice::Text)){
        return;
        }
    ui->filename_LE->setText(filename);
    clearall(); //Clear all fields before loading a new file
    QTextStream stream(&file);
    ui->rawlog_TE->clear();
    ui->errs_TE->clear();
    adif = FALSE;
    adrline = 0; // number of address lines in logfile
    sbline = 0; // Number of soapbox lines in logfile
    numqsos = 0; // number of QSOs in logfile
    allqsos = "";

      while(!stream.atEnd()){
            line = stream.readLine();
            parseit();
            if(logerr){
                // Report all errors found
                ui->errs_TE->append(line);
               // Alert button background color change
                red_btn();
            }
            if(adif){
                 ui->errs_TE->append(tr("Sorry, CabAnalyst does not support ADIF imports yet."));
                 ui->errs_TE->append(tr("File read aborted"));
               file.close();
               break;
            }
            // Last thing to do is to put the raw line of text into the Raw logfile tab
            ui->rawlog_TE->append(line);
            }
    file.close();
}

void Dialog::parseit(){
    // This routine reads a line of text and converts it, if needed, to Cabrillo 3 format.
    // It then populates the fields on the forms.
    temp = line;
    logerr = FALSE; // Reset error detector      
    if(temp.startsWith("START-OF-LOG:")){
        temp.remove("START-OF-LOG:", Qt::CaseInsensitive);
        return;
     }
    if(temp.startsWith("ARRL-SECTION:")){
        temp.remove("ARRL-SECTION: ", Qt::CaseInsensitive);
        temp.remove(QChar(' ')); // Remove pesky space characters
        ///ui->section_LE->setText(temp); // Cabrillo 2.0 spec
        ui->loc_LE->setText(temp); // For now set this to ARRL Section.
        return;
    }
    if(temp.startsWith("CATEGORY:")){
        //This is a Cabrillo 2 field that needs conversion
        temp.remove("CATEGORY: ", Qt::CaseInsensitive);
        // Category is composed of 4 fields: operator, band, power, and mode
        QString op = temp.section(' ', 0, 0);
        QString band = temp.section(' ', 1, 1);
        QString pwr = temp.section(' ', 2, 2);
        QString mode = temp.section(' ', 3, 3);
         // Populate the combo boxes with the correct values
        int idx;
        // Translate op
        if(op ==  "SINGLE-OP"){
                op = "SINGLE-OP";
                }
        if(op ==  "SINGLE-OP-ASSISTED"){
                op = "SINGLE-OP";
                }
        if(op ==  "MULTI-ONE"){
                op = "MULTI-OP";
                }
        if(op ==  "MULTI-TWO"){
                op = "MULTI-OP";
                }
        if(op ==  "MULTI-MULTI"){
                op = "MULTI-OP";
                }

        idx = ui->op_CB->findText(op, Qt::MatchContains);
        if(idx == -1){
            logerr = TRUE;
            return;
        }
        ui->op_CB->setCurrentIndex(idx);

        idx = ui->band_CB->findText(band, Qt::MatchContains);
        if(idx == -1){
            logerr = TRUE;
            return;
        }
        ui->band_CB->setCurrentIndex(idx);        

        idx = ui->pwr_CB->findText(pwr, Qt::MatchContains);
        if(idx == -1){
            logerr = TRUE;
            return;
        }
        ui->pwr_CB->setCurrentIndex(idx);

        idx = ui->mode_CB->findText(mode, Qt::MatchContains);        
        ui->mode_CB->setCurrentIndex(idx);
        return;
    }
    if(temp.startsWith("IOTA-ISLAND-NAME:")){
        // Cabrillo 2 specific field
        temp.remove("IOTA-ISLAND-NAME: ", Qt::CaseInsensitive);       
        ui->loc_LE->setText(temp); // Overwrite ARRL section
        return;
    }
    if(temp.startsWith("CATEGORY-DXPEDITION:")){
        // Cabrillo 2 specific field
        temp.remove("CATEGORY-DXPEDITION: ", Qt::CaseInsensitive);
        temp.remove(QChar(' ')); // Remove pesky space characters
        if(temp == "DXPEDITION"){
            int idx;
            idx = ui->cat_stn_CB->findText("EXPEDITION", Qt::MatchContains);
            ui->cat_stn_CB->setCurrentIndex(idx);
            }
        return;
    }
    if(temp.startsWith("CATEGORY-BAND:")){
        temp.remove("CATEGORY-BAND: ", Qt::CaseInsensitive);        
        int idx;
        idx = ui->band_CB->findText(temp, Qt::MatchContains);
        ui->band_CB->setCurrentIndex(idx);
        return;
    }
    if(temp.startsWith("CATEGORY-MODE:")){
        temp.remove("CATEGORY-MODE: ", Qt::CaseInsensitive);
        int idx;
        idx = ui->mode_CB->findText(temp, Qt::MatchContains);
        ui->mode_CB->setCurrentIndex(idx);
        return;
    }
    if(temp.startsWith("CATEGORY-OPERATOR:")){
        temp.remove("CATEGORY-OPERATOR: ", Qt::CaseInsensitive);
        int idx;
        idx = ui->op_CB->findText(temp, Qt::MatchContains);
        ui->op_CB->setCurrentIndex(idx);
        return;
    }
    if(temp.startsWith("CATEGORY-POWER:")){
        temp.remove("CATEGORY-POWER: ", Qt::CaseInsensitive);
        int idx;
        idx = ui->pwr_CB->findText(temp, Qt::MatchContains);
        ui->pwr_CB->setCurrentIndex(idx);
        return;
     }
    if(temp.startsWith("CATEGORY-STATION:")){
         temp.remove("CATEGORY-STATION: ", Qt::CaseInsensitive);
        int idx;
        idx = ui->cat_stn_CB->findText(temp, Qt::MatchContains);
        ui->cat_stn_CB->setCurrentIndex(idx);
        return;
     }
    if(temp.startsWith("CATEGORY-TRANSMITTER:")){
        temp.remove("CATEGORY-TRANSMITTER: ", Qt::CaseInsensitive);
        int idx;
        idx = ui->cat_trans_CB->findText(temp, Qt::MatchContains);
        ui->cat_trans_CB->setCurrentIndex(idx);
        return;
     }
    if(temp.startsWith("EMAIL:")){
        temp.remove("EMAIL: ", Qt::CaseInsensitive);
        ui->email_LE->setText(temp);// This really does need to be a text entry field
        return;
    }
    if(temp.startsWith("LOCATION:")){
         temp.remove("LOCATION: ", Qt::CaseInsensitive);         
         ui->loc_LE->setText(temp);// This really does need to be a text entry field
         return;
     }
    if(temp.startsWith("DEBUG:")){
        // Lets not parse this.  It will show up as an error.
        // You should not have this in your log file.
        //return;
     }
    // Cabrillo common
    if(temp.startsWith("CATEGORY-ASSISTED:")){
         temp.remove("CATEGORY-ASSISTED: ", Qt::CaseInsensitive); // Remove header
         temp.remove(QChar(' ')); // Remove pesky space characters
         //qDebug() << "DEBUG: assisted search string = " << temp;
        int idx = ui->assisted_CB->findText(temp, Qt::MatchContains);
        //qDebug() << "DEBUG: assisted index returned = " << idx;
        ui->assisted_CB->setCurrentIndex(idx);
        return;
     }
    if(temp.startsWith("CATEGORY-OVERLAY:")){
         temp.remove("CATEGORY-OVERLAY: ", Qt::CaseInsensitive);
         ui->overlay_LE->setText(temp);
         return;
     }
    if(temp.startsWith("CATEGORY-TIME:")){
        temp.remove("CATEGORY-TIME: ", Qt::CaseInsensitive);
        int idx;
        idx = ui->time_CB->findText(temp, Qt::MatchContains);
        ui->time_CB->setCurrentIndex(idx);
        return;
     }
      if(temp.startsWith("CALLSIGN:")){
         temp.remove("CALLSIGN: ", Qt::CaseInsensitive);
         ui->callsign_LE->setText(temp);
         return;
        }
    if(temp.startsWith("CATEGORY-TIME:")){
         temp.remove("CATEGORY-TIME: ", Qt::CaseInsensitive);
        int idx;
        idx = ui->time_CB->findText(temp, Qt::MatchContains);
        ui->time_CB->setCurrentIndex(idx);
         return;
     }
    if(temp.startsWith("CLAIMED-SCORE:")){
         temp.remove("CLAIMED-SCORE: ", Qt::CaseInsensitive);
         ui->score_LE->setText(temp);
         return;
     }
    if(temp.startsWith("CLUB:")){
         temp.remove("CLUB: ", Qt::CaseInsensitive);
         ui->club_LE->setText(temp);
         return;
     }

    if(temp.startsWith("CONTEST:")){
         temp.remove("CONTEST: ", Qt::CaseInsensitive);
         int idx = ui->contest_CB->findText(temp, Qt::MatchContains);
         if(idx == -1){ logerr = TRUE; }
         ui->contest_CB->setCurrentIndex(idx);
         return;
     }

    if(temp.startsWith("CREATED-BY:")){
         temp.remove("CREATED-BY: ", Qt::CaseInsensitive);         
         // Ignore this line.  Put in CabAnalyst later
         return;
     }
    if(temp.startsWith("OPERATORS:")){
         temp.remove("OPERATORS: ", Qt::CaseInsensitive);
         ui->operators_LE->setText(temp);
         return;
    }
    if(temp.startsWith("OFFTIME:")){
      // Ignore offtime.  The robot software calculates this on it's own
        return;
    }
    if(temp.startsWith("NAME:")){
        temp.remove("NAME: ", Qt::CaseInsensitive);
        ui->name_LE->setText(temp);
        return;
     }
    if(temp.startsWith("ADDRESS:")){
         temp.remove("ADDRESS: ", Qt::CaseInsensitive);
         // Possible multi line data saved. Now need to display it properly.
         adrline++;
         switch(adrline){
             case 1:
                ui->addr1_LE->setText(temp);
                break;
             case 2:
                ui->addr2_LE->setText(temp);
                break;
             case 3:
                ui->addr3_LE->setText(temp);
                break;
             default:
                qDebug() << "More than 3 Address lines, count = " << adrline;
            }
         return;
    }

    if(temp.startsWith("SOAPBOX:")){
         temp.remove("SOAPBOX:", Qt::CaseInsensitive);
         // Possible multi line data saved. Now need to display it properly.
         sbline++;
         switch(sbline){
             case 1:               
                ui->sb1_LE->setText(temp);
                break;
             case 2:
                ui->sb2_LE->setText(temp);
                break;
             case 3:
                ui->sb3_LE->setText(temp);
                break;
             default:
                qDebug() << "More than 3 Soapbox lines, count = " << sbline;
        }
     return;
    }
    if(temp.startsWith("QSO:")){
        numqsos++;
        allqsos.append(line);
        allqsos.append("\n"); // Need a CR
     return;
    }
    if(temp.startsWith("END-OF-LOG:")){
        // Print out totals and post parse results
        temp.setNum(numqsos);
        ui->num_qsos_LE->setText(temp);
        return;
    }

    // ADIF test
    if(temp.startsWith("<EOH>")){
            adif = TRUE;
            logerr = TRUE;
            return;
        }
    // Anything that gets to here should be an error!
    //qDebug() << "ERROR detected on this line" << endl << line << endl;
    logerr = TRUE;
}



void Dialog::parseV2(){
   // V2.0 Field listing
   // START-OF-LOG, END-OF-LOG, ARRL-SECTION, CALLSIGN, CATEGORY, CATEGORY-ASSISTED, CATEGORY-DXPEDITION,
   // CATEGORY-OVERLAY, CATEGORY-TIME, CLAIMED-SCORE, CLUB, CONTEST, CREATED-BY, IOTA-ISLAND-NAME,
   // NAME, ADDRESS, OPERATORS, OFFTIME, SOAPBOX, QSO    
 }


void Dialog::parseV3(){
    // v3.0 Field listing
    // START-OF-LOG, END-OF-LOG, CALLSIGN, CATEGORY, CATEGORY-ASSISTED, CATEGORY-BAND, CATEGORY-MODE,
    // CATEGORY-OPERATOR, CATEGORY-POWER, CATEGORY-STATION, CATEGORY-TIME, CATEGORY-TRANSMITTER, CATEGORY-OVERLAY,
    // CLAIMED-SCORE, CLUB, CONTEST, CREATED-BY, EMAIL, LOCATION, NAME, ADDRESS, OPERATORS, OFFTIME, SOAPBOX, QSO
    // DEBUG
}

void Dialog::parsecommon(){

/*
  Cabrillo V3.0 QSO spec
  Cabrillo QSO template for other ARRL and CQ contests, RDXC, Oceania DX Contest & AP Sprint
                                --------info sent------- -------info rcvd--------
QSO: freq  mo date       time call          rst exch   call          rst exch   t
QSO: ***** ** yyyy-mm-dd nnnn ************* nnn ****** ************* nnn ****** n
QSO:  3799 PH 1999-03-06 0711 HC8N          59  700    W1AW          59  CT     0
*/

/*
  Cabrillo V2.0 QSO spec
Cabrillo QSO template for other ARRL and CQ contests, Stew Perry contest, Oceania DX Contest & AP Sprint

                              --------info sent------- -------info rcvd--------
QSO: freq  mo date       time call          rst exch   call          rst exch   t
QSO: ***** ** yyyy-mm-dd nnnn ************* nnn ****** ************* nnn ****** n
QSO:  3799 PH 1999-03-06 0711 HC8N          59  700    W1AW          59  CT     0
000000000111111111122222222223333333333444444444455555555556666666666777777777788
123456789012345678901234567890123456789012345678901234567890123456789012345678901
*/
}





void Dialog::on_write_log_PB_clicked()
{
    // Write new Log
    QString writefile = QFileDialog::getSaveFileName(this, tr("Select logfile name to write to"), "*", tr("All files (*.*)"));
    QFile file(writefile);
   if(!file.open(QIODevice::WriteOnly | QIODevice::Text )){
         int ret = QMessageBox::critical(this, tr("CabAnalyst"),
                                tr("Cannot open file for writing\n"
                                   "Do you have permission to write to that directory?"),
                                QMessageBox::NoButton);
        return;
        }
    //qDebug() << "Logfile opened for writing" << filename;
QTextStream out(&file);

//------------------ Print header --------------------
// Make sure there is a good header first.
make_header();
out << s;
// Add all QSOs from original log
out << allqsos;
out << "END-OF-LOG: " << endl;  // Must be last line in the log file
// Close the file, all done writing
file.close();
}

void Dialog::clearall(){
    // Set all text fields to <empty>
    int idx;
    green_btn();
    other_contest = "";
    ui->callsign_LE->setText("<empty>");
    ui->overlay_LE->setText("<empty>");
    ui->outlog_TE->clear();
    ui->score_LE->setText("<empty>");
    ui->club_LE->setText("<empty>");
    ui->operators_LE->setText("<empty>");
    ui->sb1_LE->setText("<empty>");
    ui->sb2_LE->setText("<empty>");
    ui->sb3_LE->setText("<empty>");
    ui->name_LE->setText("<empty>");
    ui->addr1_LE->setText("<empty>");
    ui->addr1_LE->setText("<empty>");
    ui->addr2_LE->setText("<empty>");
    ui->addr3_LE->setText("<empty>");
    ui->section_LE->setText("<empty>");
    ui->iota_LE->setText("<empty>");
    idx = ui->dx_CB->findText("<empty>", Qt::MatchContains);
    ui->dx_CB->setCurrentIndex(idx);
    idx = ui->assisted_CB->findText("<empty>", Qt::MatchContains);
    ui->assisted_CB->setCurrentIndex(idx);
    ui->email_LE->setText("<empty>");
    ui->loc_LE->setText("<empty>");
    ui->ocontest_LE->setReadOnly(TRUE); // Disable editing in the text field
    ui->ocontest_LE->setText("You should not need this");
    //QFont font1;
    //font1.setItalic(true);
}

void Dialog::make_header(){
    // This creates a Cabrillo 3.0 header
    // It is the robot preferred format for all Cabrillo logs

// Cabrillo Common fields    
    ui->outlog_TE->clear(); // Empty the text edit box before writing new data
    s.clear();
    s.append("START-OF-LOG: 3.0");  // Always output as Cabrillo 3.0
    s.append("\n");


if(ui->callsign_LE->displayText() != "<empty>"){
    s.append("CALLSIGN: ");
    s.append(ui->callsign_LE->displayText());
    s.append("\n");
    }

if(ui->assisted_CB->currentText() != "<empty>"){
    s.append("CATEGORY-ASSISTED: ");
    s.append(ui->assisted_CB->currentText());
    s.append("\n");
    }

 if(ui->band_CB->currentText()  != "<empty>"){        
    s.append("CATEGORY-BAND: ");
    s.append(ui->band_CB->currentText());
    s.append("\n");
    }

    if(ui->mode_CB->currentText()  != "<none>"){
        //qDebug() << "Mode =" << ui->mode_CB->currentText() << "|" ;
        s.append("CATEGORY-MODE: ");// Cabrillo 3
        s.append(ui->mode_CB->currentText());
        s.append("\n");
    }

    if(ui->op_CB->currentText() != "<empty>"){
        s.append("CATEGORY-OPERATOR: ");// Cabrillo 3
        s.append(ui->op_CB->currentText());
        s.append("\n");
    }

    if(ui->pwr_CB->currentText()  != "<empty>"){
    s.append("CATEGORY-POWER: ");// Cabrillo 3
    s.append(ui->pwr_CB->currentText());
    s.append("\n");
    }

if(ui->cat_stn_CB->currentText() != "<empty>"){
    s.append("CATEGORY-STATION: ");// Cabrillo 3
    s.append(ui->cat_stn_CB->currentText());
    s.append("\n");
    }

if(ui->time_CB->currentText() != "<empty>"){
    s.append("CATEGORY-TIME: ");   
    s.append(ui->time_CB->currentText());
    s.append("\n");
    }

// CATEGORY-TRANSMITTER // Cabrillo 3

if(ui->overlay_LE->displayText() != "<empty>"){
    s.append("CATEGORY-OVERLAY: ");
    s.append(ui->overlay_LE->displayText());
    s.append("\n");
    }

if(ui->score_LE->displayText()  != "<empty>"){
    s.append("CLAIMED-SCORE: ");
    QString t = ui->score_LE->displayText();
    t.remove(QChar(',')); // Remove commas
    t.remove(QChar('.')); // Remove decimal points
    s.append(t);
    s.append("\n");
    }

if(ui->club_LE->displayText() != "<empty>"){
    s.append("CLUB: ");
    s.append(ui->club_LE->displayText());
    s.append("\n");
    }

if(ui->contest_CB->currentText()  != "<empty>" && ui->contest_CB->currentText()  != "<other>"){
    s.append("CONTEST: ");
    s.append(ui->contest_CB->currentText());
    s.append("\n");
    }

 // My advertising.  :)
    s.append("CREATED-BY: ");
    s.append(CABANALYST);
    s.append("\n");


if(ui->name_LE->displayText() != "<empty>"){    
    s.append("NAME: ");
    s.append(ui->name_LE->displayText());
    s.append("\n");
    }

if(ui->addr1_LE->displayText() != "<empty>"){    
    s.append("ADDRESS: ");
    s.append(ui->addr1_LE->displayText());
    s.append("\n");
    }

if(ui->addr2_LE->displayText() != "<empty>"){    
    s.append("ADDRESS: ");
    s.append(ui->addr2_LE->displayText());
    s.append("\n");
    }

if(ui->addr3_LE->displayText() != "<empty>"){    
    s.append("ADDRESS: ");
    s.append(ui->addr3_LE->displayText());
    s.append("\n");
    }

if(ui->operators_LE->displayText()  != "<empty>"){    
    s.append("OPERATORS: ");
    s.append(ui->operators_LE->displayText());
    s.append("\n");
    }

if(ui->sb1_LE->displayText()  != "<empty>"){    
    s.append("SOAPBOX: ");
    s.append(ui->sb1_LE->displayText());
    s.append("\n");
    }

if(ui->sb2_LE->displayText()  != "<empty>"){    
    s.append("SOAPBOX: ");
    s.append(ui->sb2_LE->displayText());
    s.append("\n");
    }

if(ui->sb3_LE->displayText()  != "<empty>"){    
    s.append("SOAPBOX: ");
    s.append(ui->sb3_LE->displayText());
    s.append("\n");
    }

ui->outlog_TE->setText(s);
}
void Dialog::on_test_PB_clicked()
{
    make_header();
}

void Dialog::on_print_log_PB_clicked()
{
    /* // Borked up
 #ifndef QT_NO_PRINTER
     QTextEdit *editor = static_cast<QTextEdit*>(letters->currentWidget());

    ui->outlog_TE->selectAll();
     QPrinter printer;

     QPrintDialog *dialog = new QPrintDialog(&printer, this);
     dialog->setWindowTitle(tr("Print Document"));
     if (editor->textCursor().hasSelection())
         dialog->addEnabledOption(QAbstractPrintDialog::PrintSelection);

     if (dialog->exec() != QDialog::Accepted)
         return;

     editor->print(&printer);
     //ui->outlog_TE->print(&printer);
 #endif
     */

   // ui->outlog_TE->print(printer);

}

void Dialog::on_contest_CB_currentIndexChanged(QString )
{
    if(ui->contest_CB->currentText()  == "<other>"){
        // Set the user defined contest name;                      
     QMessageBox::StandardButton reply;
     reply = QMessageBox::question(this, tr("Are you sure?"),
                                     tr("You want to create your own contest name?"),
                                     QMessageBox::Ok | QMessageBox::Cancel,
                                     QMessageBox::Cancel);
     if (reply == QMessageBox::Ok){
        // qDebug() << "Ok";
         ui->ocontest_LE->setReadOnly(FALSE); // Which enables editing in that text field
         ui->ocontest_LE->setText("");
         ui->ocontest_LE->setFocus();
        }
     else if (reply == QMessageBox::Cancel){
         //qDebug() << "Cancel";
         return;
        }
    }
}

void Dialog::on_error_PB_clicked()
{
    ui->tabWidget->setCurrentIndex(2);
}

void Dialog::red_btn(){
        QPalette palette;
        QBrush brush(QColor(170, 0, 0, 255)); // RED
        brush.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Button, brush);
        palette.setBrush(QPalette::Inactive, QPalette::Button, brush);
        palette.setBrush(QPalette::Disabled, QPalette::Button, brush);
        ui->error_PB->setPalette(palette);

}

void Dialog::green_btn(){
        QPalette palette;
        QBrush brush(QColor(0, 170, 0, 255)); // GREEN
        brush.setStyle(Qt::SolidPattern);
        palette.setBrush(QPalette::Active, QPalette::Button, brush);
        palette.setBrush(QPalette::Inactive, QPalette::Button, brush);
        palette.setBrush(QPalette::Disabled, QPalette::Button, brush);
        ui->error_PB->setPalette(palette);
}
